/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM imgIEncoder.idl
 */

#ifndef __gen_imgIEncoder_h__
#define __gen_imgIEncoder_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIClipboardImage; /* forward declaration */

class nsIFile; /* forward declaration */


/* starting interface:    imgIEncoder */
#define IMGIENCODER_IID_STR "ccc5b3ad-3e67-4e3d-97e1-b06b2e96fef8"

#define IMGIENCODER_IID \
  {0xccc5b3ad, 0x3e67, 0x4e3d, \
    { 0x97, 0xe1, 0xb0, 0x6b, 0x2e, 0x96, 0xfe, 0xf8 }}

/**
 * imgIEncoder interface
 *   Currently this is a very specific encoder designed to encode a native clipboard image as a JPEG out to disk.
 *   It is not intended to be a generic image encoder. 
 *   
 */
class NS_NO_VTABLE imgIEncoder : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(IMGIENCODER_IID)

  /**
    Encode a native clipboard image
  **/
  /* void encodeClipboardImage (in nsIClipboardImage aClipboardImage, out nsIFile aImageFile); */
  NS_IMETHOD EncodeClipboardImage(nsIClipboardImage *aClipboardImage, nsIFile **aImageFile) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_IMGIENCODER \
  NS_IMETHOD EncodeClipboardImage(nsIClipboardImage *aClipboardImage, nsIFile **aImageFile); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_IMGIENCODER(_to) \
  NS_IMETHOD EncodeClipboardImage(nsIClipboardImage *aClipboardImage, nsIFile **aImageFile) { return _to EncodeClipboardImage(aClipboardImage, aImageFile); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_IMGIENCODER(_to) \
  NS_IMETHOD EncodeClipboardImage(nsIClipboardImage *aClipboardImage, nsIFile **aImageFile) { return !_to ? NS_ERROR_NULL_POINTER : _to->EncodeClipboardImage(aClipboardImage, aImageFile); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public imgIEncoder
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_IMGIENCODER

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, imgIEncoder)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void encodeClipboardImage (in nsIClipboardImage aClipboardImage, out nsIFile aImageFile); */
NS_IMETHODIMP _MYCLASS_::EncodeClipboardImage(nsIClipboardImage *aClipboardImage, nsIFile **aImageFile)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_imgIEncoder_h__ */
