/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIToolkitProfile.idl
 */

#ifndef __gen_nsIToolkitProfile_h__
#define __gen_nsIToolkitProfile_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsILocalFile; /* forward declaration */

class nsIToolkitProfile; /* forward declaration */


/* starting interface:    nsIProfileLock */
#define NS_IPROFILELOCK_IID_STR "6f987826-e4dd-453d-bb66-a1e46088fced"

#define NS_IPROFILELOCK_IID \
  {0x6f987826, 0xe4dd, 0x453d, \
    { 0xbb, 0x66, 0xa1, 0xe4, 0x60, 0x88, 0xfc, 0xed }}

/**
 * Hold on to a profile lock. Once you release the last reference to this
 * interface, the profile lock is released.
 */
class NS_NO_VTABLE nsIProfileLock : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IPROFILELOCK_IID)

  /* readonly attribute nsILocalFile directory; */
  NS_IMETHOD GetDirectory(nsILocalFile * *aDirectory) = 0;

  /* void unlock (); */
  NS_IMETHOD Unlock(void) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIPROFILELOCK \
  NS_IMETHOD GetDirectory(nsILocalFile * *aDirectory); \
  NS_IMETHOD Unlock(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIPROFILELOCK(_to) \
  NS_IMETHOD GetDirectory(nsILocalFile * *aDirectory) { return _to GetDirectory(aDirectory); } \
  NS_IMETHOD Unlock(void) { return _to Unlock(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIPROFILELOCK(_to) \
  NS_IMETHOD GetDirectory(nsILocalFile * *aDirectory) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDirectory(aDirectory); } \
  NS_IMETHOD Unlock(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Unlock(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsProfileLock : public nsIProfileLock
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIPROFILELOCK

  nsProfileLock();

private:
  ~nsProfileLock();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsProfileLock, nsIProfileLock)

nsProfileLock::nsProfileLock()
{
  /* member initializers and constructor code */
}

nsProfileLock::~nsProfileLock()
{
  /* destructor code */
}

/* readonly attribute nsILocalFile directory; */
NS_IMETHODIMP nsProfileLock::GetDirectory(nsILocalFile * *aDirectory)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void unlock (); */
NS_IMETHODIMP nsProfileLock::Unlock()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIToolkitProfile */
#define NS_ITOOLKITPROFILE_IID_STR "87cea5c2-b9ed-44f9-8984-e75bc9f7134a"

#define NS_ITOOLKITPROFILE_IID \
  {0x87cea5c2, 0xb9ed, 0x44f9, \
    { 0x89, 0x84, 0xe7, 0x5b, 0xc9, 0xf7, 0x13, 0x4a }}

class NS_NO_VTABLE nsIToolkitProfile : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_ITOOLKITPROFILE_IID)

  /* readonly attribute nsILocalFile rootDir; */
  NS_IMETHOD GetRootDir(nsILocalFile * *aRootDir) = 0;

  /* attribute AUTF8String name; */
  NS_IMETHOD GetName(nsACString & aName) = 0;
  NS_IMETHOD SetName(const nsACString & aName) = 0;

  /* void remove (in boolean removeFiles); */
  NS_IMETHOD Remove(PRBool removeFiles) = 0;

  /* nsIProfileLock lock (); */
  NS_IMETHOD Lock(nsIProfileLock **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSITOOLKITPROFILE \
  NS_IMETHOD GetRootDir(nsILocalFile * *aRootDir); \
  NS_IMETHOD GetName(nsACString & aName); \
  NS_IMETHOD SetName(const nsACString & aName); \
  NS_IMETHOD Remove(PRBool removeFiles); \
  NS_IMETHOD Lock(nsIProfileLock **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSITOOLKITPROFILE(_to) \
  NS_IMETHOD GetRootDir(nsILocalFile * *aRootDir) { return _to GetRootDir(aRootDir); } \
  NS_IMETHOD GetName(nsACString & aName) { return _to GetName(aName); } \
  NS_IMETHOD SetName(const nsACString & aName) { return _to SetName(aName); } \
  NS_IMETHOD Remove(PRBool removeFiles) { return _to Remove(removeFiles); } \
  NS_IMETHOD Lock(nsIProfileLock **_retval) { return _to Lock(_retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSITOOLKITPROFILE(_to) \
  NS_IMETHOD GetRootDir(nsILocalFile * *aRootDir) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRootDir(aRootDir); } \
  NS_IMETHOD GetName(nsACString & aName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetName(aName); } \
  NS_IMETHOD SetName(const nsACString & aName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetName(aName); } \
  NS_IMETHOD Remove(PRBool removeFiles) { return !_to ? NS_ERROR_NULL_POINTER : _to->Remove(removeFiles); } \
  NS_IMETHOD Lock(nsIProfileLock **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->Lock(_retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsToolkitProfile : public nsIToolkitProfile
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSITOOLKITPROFILE

  nsToolkitProfile();

private:
  ~nsToolkitProfile();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsToolkitProfile, nsIToolkitProfile)

nsToolkitProfile::nsToolkitProfile()
{
  /* member initializers and constructor code */
}

nsToolkitProfile::~nsToolkitProfile()
{
  /* destructor code */
}

/* readonly attribute nsILocalFile rootDir; */
NS_IMETHODIMP nsToolkitProfile::GetRootDir(nsILocalFile * *aRootDir)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AUTF8String name; */
NS_IMETHODIMP nsToolkitProfile::GetName(nsACString & aName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsToolkitProfile::SetName(const nsACString & aName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void remove (in boolean removeFiles); */
NS_IMETHODIMP nsToolkitProfile::Remove(PRBool removeFiles)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIProfileLock lock (); */
NS_IMETHODIMP nsToolkitProfile::Lock(nsIProfileLock **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIToolkitProfile_h__ */
