/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIExtensionManager.idl
 */

#ifndef __gen_nsIExtensionManager_h__
#define __gen_nsIExtensionManager_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFile; /* forward declaration */

class nsIRDFDataSource; /* forward declaration */

class nsIUpdateItem; /* forward declaration */


/* starting interface:    nsIExtensionDownloadProgressListener */
#define NS_IEXTENSIONDOWNLOADPROGRESSLISTENER_IID_STR "9048223f-ec50-49e5-9866-80ee8f26179d"

#define NS_IEXTENSIONDOWNLOADPROGRESSLISTENER_IID \
  {0x9048223f, 0xec50, 0x49e5, \
    { 0x98, 0x66, 0x80, 0xee, 0x8f, 0x26, 0x17, 0x9d }}

class NS_NO_VTABLE nsIExtensionDownloadProgressListener : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IEXTENSIONDOWNLOADPROGRESSLISTENER_IID)

  /* void onStateChange (in wstring aURL, in short aState, in long aValue); */
  NS_IMETHOD OnStateChange(const PRUnichar *aURL, PRInt16 aState, PRInt32 aValue) = 0;

  /* void onProgress (in wstring aURL, in unsigned long aValue, in unsigned long aMaxValue); */
  NS_IMETHOD OnProgress(const PRUnichar *aURL, PRUint32 aValue, PRUint32 aMaxValue) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIEXTENSIONDOWNLOADPROGRESSLISTENER \
  NS_IMETHOD OnStateChange(const PRUnichar *aURL, PRInt16 aState, PRInt32 aValue); \
  NS_IMETHOD OnProgress(const PRUnichar *aURL, PRUint32 aValue, PRUint32 aMaxValue); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIEXTENSIONDOWNLOADPROGRESSLISTENER(_to) \
  NS_IMETHOD OnStateChange(const PRUnichar *aURL, PRInt16 aState, PRInt32 aValue) { return _to OnStateChange(aURL, aState, aValue); } \
  NS_IMETHOD OnProgress(const PRUnichar *aURL, PRUint32 aValue, PRUint32 aMaxValue) { return _to OnProgress(aURL, aValue, aMaxValue); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIEXTENSIONDOWNLOADPROGRESSLISTENER(_to) \
  NS_IMETHOD OnStateChange(const PRUnichar *aURL, PRInt16 aState, PRInt32 aValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnStateChange(aURL, aState, aValue); } \
  NS_IMETHOD OnProgress(const PRUnichar *aURL, PRUint32 aValue, PRUint32 aMaxValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnProgress(aURL, aValue, aMaxValue); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsExtensionDownloadProgressListener : public nsIExtensionDownloadProgressListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIEXTENSIONDOWNLOADPROGRESSLISTENER

  nsExtensionDownloadProgressListener();

private:
  ~nsExtensionDownloadProgressListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsExtensionDownloadProgressListener, nsIExtensionDownloadProgressListener)

nsExtensionDownloadProgressListener::nsExtensionDownloadProgressListener()
{
  /* member initializers and constructor code */
}

nsExtensionDownloadProgressListener::~nsExtensionDownloadProgressListener()
{
  /* destructor code */
}

/* void onStateChange (in wstring aURL, in short aState, in long aValue); */
NS_IMETHODIMP nsExtensionDownloadProgressListener::OnStateChange(const PRUnichar *aURL, PRInt16 aState, PRInt32 aValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onProgress (in wstring aURL, in unsigned long aValue, in unsigned long aMaxValue); */
NS_IMETHODIMP nsExtensionDownloadProgressListener::OnProgress(const PRUnichar *aURL, PRUint32 aValue, PRUint32 aMaxValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIExtensionManager */
#define NS_IEXTENSIONMANAGER_IID_STR "c3515b0f-99f4-453b-805e-1fdf5724d6d9"

#define NS_IEXTENSIONMANAGER_IID \
  {0xc3515b0f, 0x99f4, 0x453b, \
    { 0x80, 0x5e, 0x1f, 0xdf, 0x57, 0x24, 0xd6, 0xd9 }}

class NS_NO_VTABLE nsIExtensionManager : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IEXTENSIONMANAGER_IID)

  /* boolean start (in boolean aIsDirty); */
  NS_IMETHOD Start(PRBool aIsDirty, PRBool *_retval) = 0;

  /** 
   * Returns true if mismatches were found and the app needs to restart. 
   */
  /* boolean checkForMismatches (); */
  NS_IMETHOD CheckForMismatches(PRBool *_retval) = 0;

  /* void handleCommandLineArgs (); */
  NS_IMETHOD HandleCommandLineArgs(void) = 0;

  /* void register (); */
  NS_IMETHOD Register(void) = 0;

  enum { FLAG_INSTALL_PROFILE = 1U };

  enum { FLAG_INSTALL_GLOBAL = 2U };

  /* void installExtension (in nsIFile aXPIFile, in unsigned long aFlags); */
  NS_IMETHOD InstallExtension(nsIFile *aXPIFile, PRUint32 aFlags) = 0;

  /* void uninstallExtension (in string aExtensionID); */
  NS_IMETHOD UninstallExtension(const char *aExtensionID) = 0;

  /* void enableExtension (in string aExtensionID); */
  NS_IMETHOD EnableExtension(const char *aExtensionID) = 0;

  /* void disableExtension (in string aExtensionID); */
  NS_IMETHOD DisableExtension(const char *aExtensionID) = 0;

  /* void installTheme (in nsIFile aJARFile, in unsigned long aFlags); */
  NS_IMETHOD InstallTheme(nsIFile *aJARFile, PRUint32 aFlags) = 0;

  /* void uninstallTheme (in string aThemeID); */
  NS_IMETHOD UninstallTheme(const char *aThemeID) = 0;

  /* void enableTheme (in string aThemeID); */
  NS_IMETHOD EnableTheme(const char *aThemeID) = 0;

  /* void disableTheme (in string aThemeID); */
  NS_IMETHOD DisableTheme(const char *aThemeID) = 0;

  /* void addDownloads ([array, size_is (aItemCount)] in nsIUpdateItem aItems, in unsigned long aItemCount); */
  NS_IMETHOD AddDownloads(nsIUpdateItem **aItems, PRUint32 aItemCount) = 0;

  /* void removeDownload (in wstring aURL, in unsigned short aType); */
  NS_IMETHOD RemoveDownload(const PRUnichar *aURL, PRUint16 aType) = 0;

  /* long addDownloadObserver (in nsIExtensionDownloadProgressListener aObserver); */
  NS_IMETHOD AddDownloadObserver(nsIExtensionDownloadProgressListener *aObserver, PRInt32 *_retval) = 0;

  /* void removeDownloadObserverAt (in long aIndex); */
  NS_IMETHOD RemoveDownloadObserverAt(PRInt32 aIndex) = 0;

  /* readonly attribute boolean inSafeMode; */
  NS_IMETHOD GetInSafeMode(PRBool *aInSafeMode) = 0;

  /* void update ([array, size_is (aItemCount)] in nsIUpdateItem aItems, in unsigned long aItemCount, in unsigned long aVersionUpdateOnly); */
  NS_IMETHOD Update(nsIUpdateItem **aItems, PRUint32 aItemCount, PRUint32 aVersionUpdateOnly) = 0;

  /* void getItemList (in string aItemID, in unsigned short aType, out unsigned long aItemCount, [array, size_is (aItemCount), retval] out nsIUpdateItem aItems); */
  NS_IMETHOD GetItemList(const char *aItemID, PRUint16 aType, PRUint32 *aItemCount, nsIUpdateItem ***aItems) = 0;

  /* void moveUp (in string aItemID); */
  NS_IMETHOD MoveUp(const char *aItemID) = 0;

  /* void moveDown (in string aItemID); */
  NS_IMETHOD MoveDown(const char *aItemID) = 0;

  /* void moveTop (in string aItemID); */
  NS_IMETHOD MoveTop(const char *aItemID) = 0;

  /* readonly attribute nsIRDFDataSource datasource; */
  NS_IMETHOD GetDatasource(nsIRDFDataSource * *aDatasource) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIEXTENSIONMANAGER \
  NS_IMETHOD Start(PRBool aIsDirty, PRBool *_retval); \
  NS_IMETHOD CheckForMismatches(PRBool *_retval); \
  NS_IMETHOD HandleCommandLineArgs(void); \
  NS_IMETHOD Register(void); \
  NS_IMETHOD InstallExtension(nsIFile *aXPIFile, PRUint32 aFlags); \
  NS_IMETHOD UninstallExtension(const char *aExtensionID); \
  NS_IMETHOD EnableExtension(const char *aExtensionID); \
  NS_IMETHOD DisableExtension(const char *aExtensionID); \
  NS_IMETHOD InstallTheme(nsIFile *aJARFile, PRUint32 aFlags); \
  NS_IMETHOD UninstallTheme(const char *aThemeID); \
  NS_IMETHOD EnableTheme(const char *aThemeID); \
  NS_IMETHOD DisableTheme(const char *aThemeID); \
  NS_IMETHOD AddDownloads(nsIUpdateItem **aItems, PRUint32 aItemCount); \
  NS_IMETHOD RemoveDownload(const PRUnichar *aURL, PRUint16 aType); \
  NS_IMETHOD AddDownloadObserver(nsIExtensionDownloadProgressListener *aObserver, PRInt32 *_retval); \
  NS_IMETHOD RemoveDownloadObserverAt(PRInt32 aIndex); \
  NS_IMETHOD GetInSafeMode(PRBool *aInSafeMode); \
  NS_IMETHOD Update(nsIUpdateItem **aItems, PRUint32 aItemCount, PRUint32 aVersionUpdateOnly); \
  NS_IMETHOD GetItemList(const char *aItemID, PRUint16 aType, PRUint32 *aItemCount, nsIUpdateItem ***aItems); \
  NS_IMETHOD MoveUp(const char *aItemID); \
  NS_IMETHOD MoveDown(const char *aItemID); \
  NS_IMETHOD MoveTop(const char *aItemID); \
  NS_IMETHOD GetDatasource(nsIRDFDataSource * *aDatasource); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIEXTENSIONMANAGER(_to) \
  NS_IMETHOD Start(PRBool aIsDirty, PRBool *_retval) { return _to Start(aIsDirty, _retval); } \
  NS_IMETHOD CheckForMismatches(PRBool *_retval) { return _to CheckForMismatches(_retval); } \
  NS_IMETHOD HandleCommandLineArgs(void) { return _to HandleCommandLineArgs(); } \
  NS_IMETHOD Register(void) { return _to Register(); } \
  NS_IMETHOD InstallExtension(nsIFile *aXPIFile, PRUint32 aFlags) { return _to InstallExtension(aXPIFile, aFlags); } \
  NS_IMETHOD UninstallExtension(const char *aExtensionID) { return _to UninstallExtension(aExtensionID); } \
  NS_IMETHOD EnableExtension(const char *aExtensionID) { return _to EnableExtension(aExtensionID); } \
  NS_IMETHOD DisableExtension(const char *aExtensionID) { return _to DisableExtension(aExtensionID); } \
  NS_IMETHOD InstallTheme(nsIFile *aJARFile, PRUint32 aFlags) { return _to InstallTheme(aJARFile, aFlags); } \
  NS_IMETHOD UninstallTheme(const char *aThemeID) { return _to UninstallTheme(aThemeID); } \
  NS_IMETHOD EnableTheme(const char *aThemeID) { return _to EnableTheme(aThemeID); } \
  NS_IMETHOD DisableTheme(const char *aThemeID) { return _to DisableTheme(aThemeID); } \
  NS_IMETHOD AddDownloads(nsIUpdateItem **aItems, PRUint32 aItemCount) { return _to AddDownloads(aItems, aItemCount); } \
  NS_IMETHOD RemoveDownload(const PRUnichar *aURL, PRUint16 aType) { return _to RemoveDownload(aURL, aType); } \
  NS_IMETHOD AddDownloadObserver(nsIExtensionDownloadProgressListener *aObserver, PRInt32 *_retval) { return _to AddDownloadObserver(aObserver, _retval); } \
  NS_IMETHOD RemoveDownloadObserverAt(PRInt32 aIndex) { return _to RemoveDownloadObserverAt(aIndex); } \
  NS_IMETHOD GetInSafeMode(PRBool *aInSafeMode) { return _to GetInSafeMode(aInSafeMode); } \
  NS_IMETHOD Update(nsIUpdateItem **aItems, PRUint32 aItemCount, PRUint32 aVersionUpdateOnly) { return _to Update(aItems, aItemCount, aVersionUpdateOnly); } \
  NS_IMETHOD GetItemList(const char *aItemID, PRUint16 aType, PRUint32 *aItemCount, nsIUpdateItem ***aItems) { return _to GetItemList(aItemID, aType, aItemCount, aItems); } \
  NS_IMETHOD MoveUp(const char *aItemID) { return _to MoveUp(aItemID); } \
  NS_IMETHOD MoveDown(const char *aItemID) { return _to MoveDown(aItemID); } \
  NS_IMETHOD MoveTop(const char *aItemID) { return _to MoveTop(aItemID); } \
  NS_IMETHOD GetDatasource(nsIRDFDataSource * *aDatasource) { return _to GetDatasource(aDatasource); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIEXTENSIONMANAGER(_to) \
  NS_IMETHOD Start(PRBool aIsDirty, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->Start(aIsDirty, _retval); } \
  NS_IMETHOD CheckForMismatches(PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CheckForMismatches(_retval); } \
  NS_IMETHOD HandleCommandLineArgs(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->HandleCommandLineArgs(); } \
  NS_IMETHOD Register(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Register(); } \
  NS_IMETHOD InstallExtension(nsIFile *aXPIFile, PRUint32 aFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->InstallExtension(aXPIFile, aFlags); } \
  NS_IMETHOD UninstallExtension(const char *aExtensionID) { return !_to ? NS_ERROR_NULL_POINTER : _to->UninstallExtension(aExtensionID); } \
  NS_IMETHOD EnableExtension(const char *aExtensionID) { return !_to ? NS_ERROR_NULL_POINTER : _to->EnableExtension(aExtensionID); } \
  NS_IMETHOD DisableExtension(const char *aExtensionID) { return !_to ? NS_ERROR_NULL_POINTER : _to->DisableExtension(aExtensionID); } \
  NS_IMETHOD InstallTheme(nsIFile *aJARFile, PRUint32 aFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->InstallTheme(aJARFile, aFlags); } \
  NS_IMETHOD UninstallTheme(const char *aThemeID) { return !_to ? NS_ERROR_NULL_POINTER : _to->UninstallTheme(aThemeID); } \
  NS_IMETHOD EnableTheme(const char *aThemeID) { return !_to ? NS_ERROR_NULL_POINTER : _to->EnableTheme(aThemeID); } \
  NS_IMETHOD DisableTheme(const char *aThemeID) { return !_to ? NS_ERROR_NULL_POINTER : _to->DisableTheme(aThemeID); } \
  NS_IMETHOD AddDownloads(nsIUpdateItem **aItems, PRUint32 aItemCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddDownloads(aItems, aItemCount); } \
  NS_IMETHOD RemoveDownload(const PRUnichar *aURL, PRUint16 aType) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveDownload(aURL, aType); } \
  NS_IMETHOD AddDownloadObserver(nsIExtensionDownloadProgressListener *aObserver, PRInt32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddDownloadObserver(aObserver, _retval); } \
  NS_IMETHOD RemoveDownloadObserverAt(PRInt32 aIndex) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveDownloadObserverAt(aIndex); } \
  NS_IMETHOD GetInSafeMode(PRBool *aInSafeMode) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetInSafeMode(aInSafeMode); } \
  NS_IMETHOD Update(nsIUpdateItem **aItems, PRUint32 aItemCount, PRUint32 aVersionUpdateOnly) { return !_to ? NS_ERROR_NULL_POINTER : _to->Update(aItems, aItemCount, aVersionUpdateOnly); } \
  NS_IMETHOD GetItemList(const char *aItemID, PRUint16 aType, PRUint32 *aItemCount, nsIUpdateItem ***aItems) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetItemList(aItemID, aType, aItemCount, aItems); } \
  NS_IMETHOD MoveUp(const char *aItemID) { return !_to ? NS_ERROR_NULL_POINTER : _to->MoveUp(aItemID); } \
  NS_IMETHOD MoveDown(const char *aItemID) { return !_to ? NS_ERROR_NULL_POINTER : _to->MoveDown(aItemID); } \
  NS_IMETHOD MoveTop(const char *aItemID) { return !_to ? NS_ERROR_NULL_POINTER : _to->MoveTop(aItemID); } \
  NS_IMETHOD GetDatasource(nsIRDFDataSource * *aDatasource) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDatasource(aDatasource); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsExtensionManager : public nsIExtensionManager
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIEXTENSIONMANAGER

  nsExtensionManager();

private:
  ~nsExtensionManager();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsExtensionManager, nsIExtensionManager)

nsExtensionManager::nsExtensionManager()
{
  /* member initializers and constructor code */
}

nsExtensionManager::~nsExtensionManager()
{
  /* destructor code */
}

/* boolean start (in boolean aIsDirty); */
NS_IMETHODIMP nsExtensionManager::Start(PRBool aIsDirty, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean checkForMismatches (); */
NS_IMETHODIMP nsExtensionManager::CheckForMismatches(PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void handleCommandLineArgs (); */
NS_IMETHODIMP nsExtensionManager::HandleCommandLineArgs()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void register (); */
NS_IMETHODIMP nsExtensionManager::Register()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void installExtension (in nsIFile aXPIFile, in unsigned long aFlags); */
NS_IMETHODIMP nsExtensionManager::InstallExtension(nsIFile *aXPIFile, PRUint32 aFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void uninstallExtension (in string aExtensionID); */
NS_IMETHODIMP nsExtensionManager::UninstallExtension(const char *aExtensionID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void enableExtension (in string aExtensionID); */
NS_IMETHODIMP nsExtensionManager::EnableExtension(const char *aExtensionID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void disableExtension (in string aExtensionID); */
NS_IMETHODIMP nsExtensionManager::DisableExtension(const char *aExtensionID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void installTheme (in nsIFile aJARFile, in unsigned long aFlags); */
NS_IMETHODIMP nsExtensionManager::InstallTheme(nsIFile *aJARFile, PRUint32 aFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void uninstallTheme (in string aThemeID); */
NS_IMETHODIMP nsExtensionManager::UninstallTheme(const char *aThemeID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void enableTheme (in string aThemeID); */
NS_IMETHODIMP nsExtensionManager::EnableTheme(const char *aThemeID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void disableTheme (in string aThemeID); */
NS_IMETHODIMP nsExtensionManager::DisableTheme(const char *aThemeID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addDownloads ([array, size_is (aItemCount)] in nsIUpdateItem aItems, in unsigned long aItemCount); */
NS_IMETHODIMP nsExtensionManager::AddDownloads(nsIUpdateItem **aItems, PRUint32 aItemCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeDownload (in wstring aURL, in unsigned short aType); */
NS_IMETHODIMP nsExtensionManager::RemoveDownload(const PRUnichar *aURL, PRUint16 aType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long addDownloadObserver (in nsIExtensionDownloadProgressListener aObserver); */
NS_IMETHODIMP nsExtensionManager::AddDownloadObserver(nsIExtensionDownloadProgressListener *aObserver, PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeDownloadObserverAt (in long aIndex); */
NS_IMETHODIMP nsExtensionManager::RemoveDownloadObserverAt(PRInt32 aIndex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean inSafeMode; */
NS_IMETHODIMP nsExtensionManager::GetInSafeMode(PRBool *aInSafeMode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void update ([array, size_is (aItemCount)] in nsIUpdateItem aItems, in unsigned long aItemCount, in unsigned long aVersionUpdateOnly); */
NS_IMETHODIMP nsExtensionManager::Update(nsIUpdateItem **aItems, PRUint32 aItemCount, PRUint32 aVersionUpdateOnly)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getItemList (in string aItemID, in unsigned short aType, out unsigned long aItemCount, [array, size_is (aItemCount), retval] out nsIUpdateItem aItems); */
NS_IMETHODIMP nsExtensionManager::GetItemList(const char *aItemID, PRUint16 aType, PRUint32 *aItemCount, nsIUpdateItem ***aItems)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void moveUp (in string aItemID); */
NS_IMETHODIMP nsExtensionManager::MoveUp(const char *aItemID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void moveDown (in string aItemID); */
NS_IMETHODIMP nsExtensionManager::MoveDown(const char *aItemID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void moveTop (in string aItemID); */
NS_IMETHODIMP nsExtensionManager::MoveTop(const char *aItemID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIRDFDataSource datasource; */
NS_IMETHODIMP nsExtensionManager::GetDatasource(nsIRDFDataSource * *aDatasource)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIExtensionItemUpdater */
#define NS_IEXTENSIONITEMUPDATER_IID_STR "c0b7517f-0b3a-41a2-bde8-ba3ac8a5af47"

#define NS_IEXTENSIONITEMUPDATER_IID \
  {0xc0b7517f, 0x0b3a, 0x41a2, \
    { 0xbd, 0xe8, 0xba, 0x3a, 0xc8, 0xa5, 0xaf, 0x47 }}

class NS_NO_VTABLE nsIExtensionItemUpdater : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IEXTENSIONITEMUPDATER_IID)

  /* void checkForUpdates ([array, size_is (aItemCount)] in nsIUpdateItem aItems, in unsigned long aItemCount, in boolean aVersionUpdateOnly); */
  NS_IMETHOD CheckForUpdates(nsIUpdateItem **aItems, PRUint32 aItemCount, PRBool aVersionUpdateOnly) = 0;

  /* readonly attribute unsigned short sourceEvent; */
  NS_IMETHOD GetSourceEvent(PRUint16 *aSourceEvent) = 0;

  /* readonly attribute unsigned short updateTypes; */
  NS_IMETHOD GetUpdateTypes(PRUint16 *aUpdateTypes) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIEXTENSIONITEMUPDATER \
  NS_IMETHOD CheckForUpdates(nsIUpdateItem **aItems, PRUint32 aItemCount, PRBool aVersionUpdateOnly); \
  NS_IMETHOD GetSourceEvent(PRUint16 *aSourceEvent); \
  NS_IMETHOD GetUpdateTypes(PRUint16 *aUpdateTypes); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIEXTENSIONITEMUPDATER(_to) \
  NS_IMETHOD CheckForUpdates(nsIUpdateItem **aItems, PRUint32 aItemCount, PRBool aVersionUpdateOnly) { return _to CheckForUpdates(aItems, aItemCount, aVersionUpdateOnly); } \
  NS_IMETHOD GetSourceEvent(PRUint16 *aSourceEvent) { return _to GetSourceEvent(aSourceEvent); } \
  NS_IMETHOD GetUpdateTypes(PRUint16 *aUpdateTypes) { return _to GetUpdateTypes(aUpdateTypes); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIEXTENSIONITEMUPDATER(_to) \
  NS_IMETHOD CheckForUpdates(nsIUpdateItem **aItems, PRUint32 aItemCount, PRBool aVersionUpdateOnly) { return !_to ? NS_ERROR_NULL_POINTER : _to->CheckForUpdates(aItems, aItemCount, aVersionUpdateOnly); } \
  NS_IMETHOD GetSourceEvent(PRUint16 *aSourceEvent) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSourceEvent(aSourceEvent); } \
  NS_IMETHOD GetUpdateTypes(PRUint16 *aUpdateTypes) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUpdateTypes(aUpdateTypes); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsExtensionItemUpdater : public nsIExtensionItemUpdater
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIEXTENSIONITEMUPDATER

  nsExtensionItemUpdater();

private:
  ~nsExtensionItemUpdater();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsExtensionItemUpdater, nsIExtensionItemUpdater)

nsExtensionItemUpdater::nsExtensionItemUpdater()
{
  /* member initializers and constructor code */
}

nsExtensionItemUpdater::~nsExtensionItemUpdater()
{
  /* destructor code */
}

/* void checkForUpdates ([array, size_is (aItemCount)] in nsIUpdateItem aItems, in unsigned long aItemCount, in boolean aVersionUpdateOnly); */
NS_IMETHODIMP nsExtensionItemUpdater::CheckForUpdates(nsIUpdateItem **aItems, PRUint32 aItemCount, PRBool aVersionUpdateOnly)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute unsigned short sourceEvent; */
NS_IMETHODIMP nsExtensionItemUpdater::GetSourceEvent(PRUint16 *aSourceEvent)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute unsigned short updateTypes; */
NS_IMETHODIMP nsExtensionItemUpdater::GetUpdateTypes(PRUint16 *aUpdateTypes)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIExtensionManager_h__ */
