/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2002
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/**
 * This is the interface to the Popup Window Manager: an object which
 * maintains popup window permissions by website.
 */

#include "nsISupports.idl"

interface nsIObserver;
interface nsISimpleEnumerator;
interface nsIURI;

[scriptable, uuid(2e14fec9-e8e9-44cc-8c86-c8673c2383cc)]
interface nsIPopupWindowManager : nsISupports {

  /**
   * These values are returned by the testPermission method
   */
  const PRUint32 ALLOW_POPUP = 1;
  const PRUint32 DENY_POPUP = 2;
  const PRUint32 ALLOW_POPUP_WITH_PREJUDICE = 3;

  /**
   * The manager's default permission can be ALLOW_POPUP (a blacklist)
   * or DENY_POPUP (a whitelist).
   */
  attribute PRUint32 defaultPermission;

  /**
   * Test whether a website has permission to show a popup window.
   * @param   uri is the URI to be tested
   * @return  one of the enumerated permission actions defined above
   */
  PRUint32 testPermission(in nsIURI uri);
};

%{ C++
// {2e14fec9-e8e9-44cc-8c86-c8673c2383cc}
#define NS_POPUPWINDOWMANAGER_IID \
{ 0x2e14fec9, 0xe8e9, 0x44cc, { 0x8c, 0x86, 0xc8, 0x67, 0x3c, 0x23, 0x83,0xcc }}
#define NS_POPUPWINDOWMANAGER_CONTRACTID "@mozilla.org/PopupWindowManager;1"

#define PPM_CHANGE_NOTIFICATION "popup-perm-change"
%}
