/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is mozilla.org code.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation.  Portions created by Netscape are
 * Copyright (C) 2001 Netscape Communications Corporation.
 * All Rights Reserved.
 * 
 * Contributor(s):
 *   Scott MacGregor <mscott@mozilla.org>
 */

#include "nsISupports.idl"

interface nsIClipboardImage;
interface nsIFile;

/**
 * imgIEncoder interface
 *   Currently this is a very specific encoder designed to encode a native clipboard image as a JPEG out to disk.
 *   It is not intended to be a generic image encoder. 
 *   
 */

[scriptable, uuid(CCC5B3AD-3E67-4e3d-97E1-B06B2E96FEF8)]
interface imgIEncoder : nsISupports
{
  /**
    Encode a native clipboard image
  **/

  void encodeClipboardImage(in nsIClipboardImage aClipboardImage, out nsIFile aImageFile);
    
};
