/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIEvaluateStringProxy.idl
 */

#ifndef __gen_nsIEvaluateStringProxy_h__
#define __gen_nsIEvaluateStringProxy_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIChannel; /* forward declaration */


/* starting interface:    nsIEvaluateStringProxy */
#define NS_IEVALUATESTRINGPROXY_IID_STR "67411da0-7c2e-11d3-8c67-00609792278c"

#define NS_IEVALUATESTRINGPROXY_IID \
  {0x67411da0, 0x7c2e, 0x11d3, \
    { 0x8c, 0x67, 0x00, 0x60, 0x97, 0x92, 0x27, 0x8c }}

class NS_NO_VTABLE nsIEvaluateStringProxy : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IEVALUATESTRINGPROXY_IID)

  /**
     * Channel of the javascript: url to evaluate:
     */
  /* void init (in nsIChannel channel); */
  NS_IMETHOD Init(nsIChannel *channel) = 0;

  /**
     * Cause the evaluation to happen:
     */
  /* void evaluateString (out string aRetValue, out boolean aIsUndefined); */
  NS_IMETHOD EvaluateString(char **aRetValue, PRBool *aIsUndefined) = 0;

  /**
     * Create or focus the JavaScript console.
     */
  /* void bringUpConsole (); */
  NS_IMETHOD BringUpConsole(void) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIEVALUATESTRINGPROXY \
  NS_IMETHOD Init(nsIChannel *channel); \
  NS_IMETHOD EvaluateString(char **aRetValue, PRBool *aIsUndefined); \
  NS_IMETHOD BringUpConsole(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIEVALUATESTRINGPROXY(_to) \
  NS_IMETHOD Init(nsIChannel *channel) { return _to Init(channel); } \
  NS_IMETHOD EvaluateString(char **aRetValue, PRBool *aIsUndefined) { return _to EvaluateString(aRetValue, aIsUndefined); } \
  NS_IMETHOD BringUpConsole(void) { return _to BringUpConsole(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIEVALUATESTRINGPROXY(_to) \
  NS_IMETHOD Init(nsIChannel *channel) { return !_to ? NS_ERROR_NULL_POINTER : _to->Init(channel); } \
  NS_IMETHOD EvaluateString(char **aRetValue, PRBool *aIsUndefined) { return !_to ? NS_ERROR_NULL_POINTER : _to->EvaluateString(aRetValue, aIsUndefined); } \
  NS_IMETHOD BringUpConsole(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->BringUpConsole(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsEvaluateStringProxy : public nsIEvaluateStringProxy
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIEVALUATESTRINGPROXY

  nsEvaluateStringProxy();

private:
  ~nsEvaluateStringProxy();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsEvaluateStringProxy, nsIEvaluateStringProxy)

nsEvaluateStringProxy::nsEvaluateStringProxy()
{
  /* member initializers and constructor code */
}

nsEvaluateStringProxy::~nsEvaluateStringProxy()
{
  /* destructor code */
}

/* void init (in nsIChannel channel); */
NS_IMETHODIMP nsEvaluateStringProxy::Init(nsIChannel *channel)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void evaluateString (out string aRetValue, out boolean aIsUndefined); */
NS_IMETHODIMP nsEvaluateStringProxy::EvaluateString(char **aRetValue, PRBool *aIsUndefined)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void bringUpConsole (); */
NS_IMETHODIMP nsEvaluateStringProxy::BringUpConsole()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIEvaluateStringProxy_h__ */
