/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIDocShellTreeOwnerTmp.idl
 */

#ifndef __gen_nsIDocShellTreeOwnerTmp_h__
#define __gen_nsIDocShellTreeOwnerTmp_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDocShellTreeItem; /* forward declaration */


/* starting interface:    nsIDocShellTreeOwnerTmp */
#define NS_IDOCSHELLTREEOWNERTMP_IID_STR "739feaca-800c-4086-943c-d5c460d233cb"

#define NS_IDOCSHELLTREEOWNERTMP_IID \
  {0x739feaca, 0x800c, 0x4086, \
    { 0x94, 0x3c, 0xd5, 0xc4, 0x60, 0xd2, 0x33, 0xcb }}

class NS_NO_VTABLE nsIDocShellTreeOwnerTmp : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IDOCSHELLTREEOWNERTMP_IID)

  /* nsIDocShellTreeItem findItemWithNameTmp (in wstring name, in nsIDocShellTreeItem aRequestor, in nsIDocShellTreeItem aOriginalRequestor); */
  NS_IMETHOD FindItemWithNameTmp(const PRUnichar *name, nsIDocShellTreeItem *aRequestor, nsIDocShellTreeItem *aOriginalRequestor, nsIDocShellTreeItem **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOCSHELLTREEOWNERTMP \
  NS_IMETHOD FindItemWithNameTmp(const PRUnichar *name, nsIDocShellTreeItem *aRequestor, nsIDocShellTreeItem *aOriginalRequestor, nsIDocShellTreeItem **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOCSHELLTREEOWNERTMP(_to) \
  NS_IMETHOD FindItemWithNameTmp(const PRUnichar *name, nsIDocShellTreeItem *aRequestor, nsIDocShellTreeItem *aOriginalRequestor, nsIDocShellTreeItem **_retval) { return _to FindItemWithNameTmp(name, aRequestor, aOriginalRequestor, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOCSHELLTREEOWNERTMP(_to) \
  NS_IMETHOD FindItemWithNameTmp(const PRUnichar *name, nsIDocShellTreeItem *aRequestor, nsIDocShellTreeItem *aOriginalRequestor, nsIDocShellTreeItem **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->FindItemWithNameTmp(name, aRequestor, aOriginalRequestor, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDocShellTreeOwnerTmp : public nsIDocShellTreeOwnerTmp
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOCSHELLTREEOWNERTMP

  nsDocShellTreeOwnerTmp();

private:
  ~nsDocShellTreeOwnerTmp();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDocShellTreeOwnerTmp, nsIDocShellTreeOwnerTmp)

nsDocShellTreeOwnerTmp::nsDocShellTreeOwnerTmp()
{
  /* member initializers and constructor code */
}

nsDocShellTreeOwnerTmp::~nsDocShellTreeOwnerTmp()
{
  /* destructor code */
}

/* nsIDocShellTreeItem findItemWithNameTmp (in wstring name, in nsIDocShellTreeItem aRequestor, in nsIDocShellTreeItem aOriginalRequestor); */
NS_IMETHODIMP nsDocShellTreeOwnerTmp::FindItemWithNameTmp(const PRUnichar *name, nsIDocShellTreeItem *aRequestor, nsIDocShellTreeItem *aOriginalRequestor, nsIDocShellTreeItem **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDocShellTreeOwnerTmp_h__ */
